@@ -17,21 +17,24 @@
 #IF97_REGION <- c(WATER = 1L, STEAM = 2L, SUPER = 3L, SAT = 4L, GAZ = 5L)
 
 if97_region <- function(p, t)
-	callWrapper(R_if97_region, p = p, t = t)
+	callWrapper(C_if97_region, p = p, t = t)
 
-if97_state <- function(p, t) {
-	s <- callWrapper(R_if97_state, p = p, t = t)
+if97_state <- function(p, t)
+{
+	s <- callWrapper(C_if97_state, p = p, t = t)
 	names(.IAPWS_STATE)[match(s, .IAPWS_STATE)]
 }
 
-if97_psat <- function(t) {
-	x <- callWrapper(R_if97_psat, t = t)
+if97_psat <- function(t)
+{
+	x <- callWrapper(C_if97_psat, t = t)
 	is.na(x) <- x == 0
 	x
 }
 
-if97_tsat <- function(p) {
-	x <- callWrapper(R_if97_tsat, p = p)
+if97_tsat <- function(p)
+{
+	x <- callWrapper(C_if97_tsat, p = p)
 	is.na(x) <- x == 0
 	x
 }
@@ -40,7 +43,7 @@ if97 <- function(what, p, t, state = if97_state(p, t))
 {
 	w <- .check_what(what)
 	s <- .check_state(state)
-	x <- callWrapper(R_if97, w = w, p = p, t = t, s = s,
+	x <- callWrapper(C_if97, w = w, p = p, t = t, s = s,
 			 what = c("integer", "double", "double", "integer"))
 	colnames(x) <- what
 	x
